intelmq.bots.experts.do_portal package — intelmq 3.0.0.alpha.1 documentation

# intelmq.bots.experts.do_portal package

## Submodules

## intelmq.bots.experts.do_portal.expert module

As the frontend reverse-proxies the (backend) API a “502 Bad Gateway” status code is treated the same as a timeout, i.e. will be retried instead of a fail.

`intelmq.bots.experts.do_portal.expert.` `BOT`

  alias of `intelmq.bots.experts.do_portal.expert.DoPortalExpertBot`

class `intelmq.bots.experts.do_portal.expert.` `DoPortalExpertBot`(bot_id: str, start: bool = False, sighup_event=None, disable_multithreading: Optional[bool] = None)

  Bases: `intelmq.lib.bot.Bot`

  Retrieve abuse contact information for the source IP address from a do-portal instance

  `init`()
  `mode`: str = 'append'
  `portal_api_key`: str = None
  `portal_url`: str = None
  `process`()

## Module contents